# Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
--- a/src/Makefile.am	2015-05-06 22:46:42.000000000 +0200
+++ b/src/Makefile.am	2017-02-13 23:27:56.026088988 +0100
@@ -64,3 +64,41 @@ cirrus_laguna_la_SOURCES += \
          lg_xaa.c \
          lg_xaa.h
 endif
+
+
+# Generate linker mapfiles for symbols found in other modules and use them
+# and library flag additions to make sure all symbols are resolvable
+
+MAPFILES = \
+	mapfile-cirrus_drv-external	 	\
+	mapfile-cirrus_alpine-external 	\
+	mapfile-cirrus_laguna-external
+
+BUILT_SOURCES = $(MAPFILES)
+
+cirrus_drv_la_LDFLAGS += \
+	-Wl,-M,mapfile-cirrus_alpine-external \
+	-Wl,-M,mapfile-cirrus_laguna-external \
+	-lpciaccess -lvgahw -lvbe
+
+cirrus_alpine_la_LDFLAGS += \
+	-Wl,-M,mapfile-cirrus_drv-external \
+	-lfb -lint10 -lpciaccess -lshadowfb -lvgahw
+
+cirrus_laguna_la_LDFLAGS += \
+	-Wl,-M,mapfile-cirrus_drv-external \
+	-lfb -lint10 -lvgahw
+
+mapfiles: $(MAPFILES)
+
+mapfile-cirrus_drv-external: $(cirrus_drv_la_OBJECTS)
+mapfile-cirrus_alpine-external: $(cirrus_alpine_la_OBJECTS)
+mapfile-cirrus_laguna-external: $(cirrus_laguna_la_OBJECTS)
+
+mapfile-%-external: 
+	-rm -f $@
+	printf '# Functions exported to loadable modules\n\n' > $@
+	printf '{\n  global:\n' >> $@
+	/usr/ccs/bin/nm -g $? | grep -v UNDEF | sed -n -e 's/^.*\|FUNC \|GLOB \|.*\|\(.*\)$$/    \1 = FUNCTION extern;/p' -e 's/^.*\|OBJT \|GLOB \|.*\|\(.*\)$$/    \1 = DATA extern;/p' >> $@
+	printf '};\n' >> $@
+
